@@ -3,7 +3,7 @@
  * Programmer(s): Radu Serban @ LLNL
  * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2025, Lawrence Livermore National Security,
+ * Copyright (c) 2025-2026, Lawrence Livermore National Security,
  * University of Maryland Baltimore County, and the SUNDIALS contributors.
  * Copyright (c) 2013-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
@@ -713,6 +713,10 @@ int CVodeCreateB(void* cvode_mem, int lmmB, int* which)
     return (CV_MEM_FAIL);
   }
 
+  /* We need to ensure Ns is set in the new CVODES object so that Ns is accessible 
+     in the Python callbacks which only have access to cvodeB_mem, not the original cvode_mem */
+  ((CVodeMem)cvodeB_mem)->cv_Ns = cv_mem->cv_Ns;
+
   CVodeSetUserData(cvodeB_mem, cvode_mem);
 
   CVodeSetMaxHnilWarns(cvodeB_mem, -1);
