@@ -3,7 +3,7 @@
  *                Aaron Collier @ LLNL
  * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2025, Lawrence Livermore National Security,
+ * Copyright (c) 2025-2026, Lawrence Livermore National Security,
  * University of Maryland Baltimore County, and the SUNDIALS contributors.
  * Copyright (c) 2013-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
@@ -577,14 +577,12 @@ int IDASetConstraints(void* ida_mem, N_Vector constraints)
 
   if (constraints == NULL)
   {
-    if (IDA_mem->ida_constraintsMallocDone)
+    if (IDA_mem->ida_constraints)
     {
       N_VDestroy(IDA_mem->ida_constraints);
       IDA_mem->ida_lrw -= IDA_mem->ida_lrw1;
       IDA_mem->ida_liw -= IDA_mem->ida_liw1;
     }
-    IDA_mem->ida_constraintsMallocDone = SUNFALSE;
-    IDA_mem->ida_constraintsSet        = SUNFALSE;
     return (IDA_SUCCESS);
   }
 
@@ -610,23 +608,87 @@ int IDASetConstraints(void* ida_mem, N_Vector constraints)
     return (IDA_ILL_INPUT);
   }
 
-  if (!(IDA_mem->ida_constraintsMallocDone))
+  if (!(IDA_mem->ida_constraints))
   {
     IDA_mem->ida_constraints = N_VClone(constraints);
+    if (IDA_mem->ida_constraints == NULL)
+    {
+      IDAProcessError(IDA_mem, IDA_MEM_NULL, __LINE__, __func__, __FILE__,
+                      MSG_MEM_FAIL);
+      return (IDA_MEM_NULL);
+    }
     IDA_mem->ida_lrw += IDA_mem->ida_lrw1;
     IDA_mem->ida_liw += IDA_mem->ida_liw1;
-    IDA_mem->ida_constraintsMallocDone = SUNTRUE;
   }
 
   /* Load the constraints vector */
 
   N_VScale(ONE, constraints, IDA_mem->ida_constraints);
 
-  IDA_mem->ida_constraintsSet = SUNTRUE;
-
   return (IDA_SUCCESS);
 }
 
+/*
+ * IDASetMaxNumConstraintFails
+ *
+ * Set the maximum number of constraint failure allowed in a step
+ */
+
+int IDASetMaxNumConstraintFails(void* ida_mem, int max_fails)
+{
+  if (ida_mem == NULL)
+  {
+    IDAProcessError(NULL, IDA_MEM_NULL, __LINE__, __func__, __FILE__, MSG_NO_MEM);
+    return (IDA_MEM_NULL);
+  }
+  IDAMem IDA_mem = (IDAMem)ida_mem;
+
+  if (max_fails <= 0) { IDA_mem->max_constraint_fails = MAX_CONSTRAINT_FAILS; }
+  else { IDA_mem->max_constraint_fails = max_fails; }
+
+  return IDA_SUCCESS;
+}
+
+/*
+ * IDAGetNumConstraintFails
+ *
+ * Get the number of failed steps due to constraint violation
+ */
+
+int IDAGetNumConstraintFails(void* ida_mem, long int* num_fails_out)
+{
+  if (ida_mem == NULL)
+  {
+    IDAProcessError(NULL, IDA_MEM_NULL, __LINE__, __func__, __FILE__, MSG_NO_MEM);
+    return (IDA_MEM_NULL);
+  }
+  IDAMem IDA_mem = (IDAMem)ida_mem;
+
+  *num_fails_out = IDA_mem->constraint_fails;
+
+  return IDA_SUCCESS;
+}
+
+/*
+ * IDAGetNumConstraintCorrections
+ *
+ * Get the number of constraint corrections
+ */
+
+int IDAGetNumConstraintCorrections(void* ida_mem, long int* num_corrections_out)
+{
+  if (ida_mem == NULL)
+  {
+    IDAProcessError(NULL, IDA_MEM_NULL, __LINE__, __func__, __FILE__, MSG_NO_MEM);
+    return (IDA_MEM_NULL);
+  }
+  IDAMem IDA_mem = (IDAMem)ida_mem;
+
+  *num_corrections_out = IDA_mem->constraint_corrections;
+
+  return IDA_SUCCESS;
+}
+
 /*
  * IDASetRootDirection
  *
@@ -1426,10 +1488,15 @@ int IDAPrintAllStats(void* ida_mem, FILE* outfile, SUNOutputFormat fmt)
     return (IDA_ILL_INPUT);
   }
 
+  /* step and method stats */
   sunfprintf_real(outfile, fmt, SUNTRUE, "Current time", IDA_mem->ida_tn);
   sunfprintf_long(outfile, fmt, SUNFALSE, "Steps", IDA_mem->ida_nst);
   sunfprintf_long(outfile, fmt, SUNFALSE, "Error test fails", IDA_mem->ida_netf);
   sunfprintf_long(outfile, fmt, SUNFALSE, "NLS step fails", IDA_mem->ida_ncfn);
+  sunfprintf_long(outfile, fmt, SUNFALSE, "Constraint fails",
+                  IDA_mem->constraint_fails);
+  sunfprintf_long(outfile, fmt, SUNFALSE, "Constraint corrections",
+                  IDA_mem->constraint_corrections);
   sunfprintf_real(outfile, fmt, SUNFALSE, "Initial step size", IDA_mem->ida_h0u);
   sunfprintf_real(outfile, fmt, SUNFALSE, "Last step size", IDA_mem->ida_hused);
   sunfprintf_real(outfile, fmt, SUNFALSE, "Current step size", IDA_mem->ida_hh);
@@ -1517,6 +1584,8 @@ char* IDAGetReturnFlagName(long int flag)
   case IDA_ILL_INPUT: sprintf(name, "IDA_ILL_INPUT"); break;
   case IDA_NO_MALLOC: sprintf(name, "IDA_NO_MALLOC"); break;
   case IDA_BAD_T: sprintf(name, "IDA_BAD_T"); break;
+  case IDA_BAD_K: sprintf(name, "IDA_BAD_K"); break;
+  case IDA_BAD_DKY: sprintf(name, "IDA_BAD_DKY"); break;
   case IDA_BAD_EWT: sprintf(name, "IDA_BAD_EWT"); break;
   case IDA_NO_RECOVERY: sprintf(name, "IDA_NO_RECOVERY"); break;
   case IDA_LINESEARCH_FAIL: sprintf(name, "IDA_LINESEARCH_FAIL"); break;
