@@ -3,7 +3,7 @@
  *                David J. Gardner, Radu Serban and Aaron Collier @ LLNL
  *-----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2025, Lawrence Livermore National Security,
+ * Copyright (c) 2025-2026, Lawrence Livermore National Security,
  * University of Maryland Baltimore County, and the SUNDIALS contributors.
  * Copyright (c) 2013-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
@@ -1209,7 +1209,7 @@ int kinLsSolve(KINMem kin_mem, N_Vector xx, N_Vector bb, sunrealtype* sJpnorm,
 {
   KINLsMem kinls_mem;
   int nli_inc, retval;
-  sunrealtype res_norm, tol;
+  sunrealtype tol;
 
   /* Access KINLsMem structure */
   if (kin_mem->kin_lmem == NULL)
@@ -1239,21 +1239,23 @@ int kinLsSolve(KINMem kin_mem, N_Vector xx, N_Vector bb, sunrealtype* sJpnorm,
   retval = SUNLinSolSolve(kinls_mem->LS, kinls_mem->J, xx, bb, tol);
 
   /* Retrieve solver statistics */
-  res_norm = ZERO;
-  if (kinls_mem->LS->ops->resnorm)
-  {
-    res_norm = SUNLinSolResNorm(kinls_mem->LS);
-  }
   nli_inc = 0;
   if (kinls_mem->LS->ops->numiters)
   {
     nli_inc = SUNLinSolNumIters(kinls_mem->LS);
   }
 
-#if SUNDIALS_LOGGING_LEVEL >= SUNDIALS_LOGLEVEL_INFO
+#if SUNDIALS_LOGGING_LEVEL >= SUNDIALS_LOGGING_INFO
   if (kinls_mem->iterative)
   {
     KINPrintInfo(kin_mem, PRNT_NLI, "KINLS", __func__, INFO_NLI, nli_inc);
+
+    if (kinls_mem->LS->ops->resnorm)
+    {
+      sunrealtype res_norm = SUNLinSolResNorm(kinls_mem->LS);
+      KINPrintInfo(kin_mem, PRNT_EPS, "KINLS", __func__, INFO_EPS, res_norm,
+                   kin_mem->kin_eps);
+    }
   }
 #endif
 
@@ -1334,14 +1336,6 @@ int kinLsSolve(KINMem kin_mem, N_Vector xx, N_Vector bb, sunrealtype* sJpnorm,
     }
   }
 
-#if SUNDIALS_LOGGING_LEVEL >= SUNDIALS_LOGLEVEL_INFO
-  if (kin_mem->kin_inexact_ls)
-  {
-    KINPrintInfo(kin_mem, PRNT_EPS, "KINLS", __func__, INFO_EPS, res_norm,
-                 kin_mem->kin_eps);
-  }
-#endif
-
   return (0);
 }
 
