@@ -4,7 +4,7 @@
  *                Alan C. Hindmarsh and Radu Serban @ LLNL
  * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2025, Lawrence Livermore National Security,
+ * Copyright (c) 2025-2026, Lawrence Livermore National Security,
  * University of Maryland Baltimore County, and the SUNDIALS contributors.
  * Copyright (c) 2013-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
@@ -524,7 +524,7 @@ int SUNLinSolSolve_SPGMR(SUNLinearSolver S, SUNDIALS_MAYBE_UNUSED SUNMatrix A,
 
   SUNLogInfo(S->sunctx->logger, "linear-solver", "solver = spgmr");
 
-  SUNLogInfo(S->sunctx->logger, "begin-linear-iterate", "");
+  SUNLogInfo(S->sunctx->logger, "begin-iterations-list", "");
 
   /* Set vtemp and V[0] to initial (unscaled) residual r_0 = b - A*x_0 */
   if (*zeroguess)
@@ -541,7 +541,7 @@ int SUNLinSolSolve_SPGMR(SUNLinearSolver S, SUNDIALS_MAYBE_UNUSED SUNMatrix A,
       LASTFLAG(S) = (status < 0) ? SUNLS_ATIMES_FAIL_UNREC
                                  : SUNLS_ATIMES_FAIL_REC;
 
-      SUNLogInfo(S->sunctx->logger, "end-linear-iterate",
+      SUNLogInfo(S->sunctx->logger, "end-iterations-list",
                  "status = failed matvec, retval = %d", status);
 
       return (LASTFLAG(S));
@@ -562,7 +562,7 @@ int SUNLinSolSolve_SPGMR(SUNLinearSolver S, SUNDIALS_MAYBE_UNUSED SUNMatrix A,
       LASTFLAG(S) = (status < 0) ? SUNLS_PSOLVE_FAIL_UNREC
                                  : SUNLS_PSOLVE_FAIL_REC;
 
-      SUNLogInfo(S->sunctx->logger, "end-linear-iterate",
+      SUNLogInfo(S->sunctx->logger, "end-iterations-list",
                  "status = failed preconditioner solve, retval = %d", status);
 
       return (LASTFLAG(S));
@@ -596,15 +596,17 @@ int SUNLinSolSolve_SPGMR(SUNLinearSolver S, SUNDIALS_MAYBE_UNUSED SUNMatrix A,
     *zeroguess  = SUNFALSE;
     LASTFLAG(S) = SUN_SUCCESS;
 
-    SUNLogInfo(S->sunctx->logger,
-               "end-linear-iterate", "cur-iter = 0, total-iters = 0, res-norm = %.16g, status = success",
+    SUNLogInfo(S->sunctx->logger, "end-iterations-list",
+               "cur-iter = 0, total-iters = 0, res-norm = " SUN_FORMAT_G
+               ", status = success",
                *res_norm);
 
     return (LASTFLAG(S));
   }
 
-  SUNLogInfo(S->sunctx->logger,
-             "end-linear-iterate", "cur-iter = 0, total-iters = 0, res-norm = %.16g, status = continue",
+  SUNLogInfo(S->sunctx->logger, "end-iterations-list",
+             "cur-iter = 0, total-iters = 0, res-norm = " SUN_FORMAT_G
+             ", status = continue",
              *res_norm);
 
   /* Initialize rho to avoid compiler warning message */
@@ -631,7 +633,7 @@ int SUNLinSolSolve_SPGMR(SUNLinearSolver S, SUNDIALS_MAYBE_UNUSED SUNMatrix A,
     /* Inner loop: generate Krylov sequence and Arnoldi basis */
     for (l = 0; l < l_max; l++)
     {
-      SUNLogInfo(S->sunctx->logger, "begin-linear-iterate", "");
+      SUNLogInfo(S->sunctx->logger, "begin-iterations-list", "");
 
       (*nli)++;
       krydim = l_plus_1 = l + 1;
@@ -662,7 +664,7 @@ int SUNLinSolSolve_SPGMR(SUNLinearSolver S, SUNDIALS_MAYBE_UNUSED SUNMatrix A,
           LASTFLAG(S) = (status < 0) ? SUNLS_PSOLVE_FAIL_UNREC
                                      : SUNLS_PSOLVE_FAIL_REC;
 
-          SUNLogInfo(S->sunctx->logger, "end-linear-iterate",
+          SUNLogInfo(S->sunctx->logger, "end-iterations-list",
                      "status = failed preconditioner solve, retval = %d", status);
 
           return (LASTFLAG(S));
@@ -677,7 +679,7 @@ int SUNLinSolSolve_SPGMR(SUNLinearSolver S, SUNDIALS_MAYBE_UNUSED SUNMatrix A,
         LASTFLAG(S) = (status < 0) ? SUNLS_ATIMES_FAIL_UNREC
                                    : SUNLS_ATIMES_FAIL_REC;
 
-        SUNLogInfo(S->sunctx->logger, "end-linear-iterate",
+        SUNLogInfo(S->sunctx->logger, "end-iterations-list",
                    "status = failed matvec, retval = %d", status);
 
         return (LASTFLAG(S));
@@ -693,7 +695,7 @@ int SUNLinSolSolve_SPGMR(SUNLinearSolver S, SUNDIALS_MAYBE_UNUSED SUNMatrix A,
           LASTFLAG(S) = (status < 0) ? SUNLS_PSOLVE_FAIL_UNREC
                                      : SUNLS_PSOLVE_FAIL_REC;
 
-          SUNLogInfo(S->sunctx->logger, "end-linear-iterate",
+          SUNLogInfo(S->sunctx->logger, "end-iterations-list",
                      "status = failed preconditioner solve, retval = %d", status);
 
           return (LASTFLAG(S));
@@ -734,7 +736,7 @@ int SUNLinSolSolve_SPGMR(SUNLinearSolver S, SUNDIALS_MAYBE_UNUSED SUNMatrix A,
         *zeroguess  = SUNFALSE;
         LASTFLAG(S) = SUNLS_QRFACT_FAIL;
 
-        SUNLogInfo(S->sunctx->logger, "end-linear-iterate",
+        SUNLogInfo(S->sunctx->logger, "end-iterations-list",
                    "status = failed QR factorization");
 
         return (LASTFLAG(S));
@@ -745,8 +747,8 @@ int SUNLinSolSolve_SPGMR(SUNLinearSolver S, SUNDIALS_MAYBE_UNUSED SUNMatrix A,
       *res_norm = rho = SUNRabs(rotation_product * r_norm);
 
       SUNLogInfo(S->sunctx->logger, "linear-iterate",
-                 "cur-iter = %i, total-iters = %i, res-norm = %.16g", l + 1,
-                 *nli, *res_norm);
+                 "cur-iter = %i, total-iters = %i, res-norm = " SUN_FORMAT_G,
+                 l + 1, *nli, *res_norm);
 
       if (rho <= delta)
       {
@@ -758,7 +760,7 @@ int SUNLinSolSolve_SPGMR(SUNLinearSolver S, SUNDIALS_MAYBE_UNUSED SUNMatrix A,
       N_VScale(ONE / Hes[l_plus_1][l], V[l_plus_1], V[l_plus_1]);
       SUNCheckLastErr();
 
-      SUNLogInfoIf(l < l_max - 1, S->sunctx->logger, "end-linear-iterate",
+      SUNLogInfoIf(l < l_max - 1, S->sunctx->logger, "end-iterations-list",
                    "status = continue");
     }
 
@@ -772,7 +774,7 @@ int SUNLinSolSolve_SPGMR(SUNLinearSolver S, SUNDIALS_MAYBE_UNUSED SUNMatrix A,
       *zeroguess  = SUNFALSE;
       LASTFLAG(S) = SUNLS_QRSOL_FAIL;
 
-      SUNLogInfo(S->sunctx->logger, "end-linear-iterate",
+      SUNLogInfo(S->sunctx->logger, "end-iterations-list",
                  "status = failed QR solve");
 
       return (LASTFLAG(S));
@@ -808,7 +810,7 @@ int SUNLinSolSolve_SPGMR(SUNLinearSolver S, SUNDIALS_MAYBE_UNUSED SUNMatrix A,
           LASTFLAG(S) = (status < 0) ? SUNLS_PSOLVE_FAIL_UNREC
                                      : SUNLS_PSOLVE_FAIL_REC;
 
-          SUNLogInfo(S->sunctx->logger, "end-linear-iterate",
+          SUNLogInfo(S->sunctx->logger, "end-iterations-list",
                      "status = failed preconditioner solve, retval = %d", status);
 
           return (LASTFLAG(S));
@@ -835,7 +837,7 @@ int SUNLinSolSolve_SPGMR(SUNLinearSolver S, SUNDIALS_MAYBE_UNUSED SUNMatrix A,
       *zeroguess  = SUNFALSE;
       LASTFLAG(S) = SUN_SUCCESS;
 
-      SUNLogInfo(S->sunctx->logger, "end-linear-iterate", "status = success");
+      SUNLogInfo(S->sunctx->logger, "end-iterations-list", "status = success");
 
       return (LASTFLAG(S));
     }
@@ -865,7 +867,7 @@ int SUNLinSolSolve_SPGMR(SUNLinearSolver S, SUNDIALS_MAYBE_UNUSED SUNMatrix A,
     }
     SUNCheckCall(N_VLinearCombination(krydim + 1, cv, Xv, V[0]));
 
-    SUNLogInfo(S->sunctx->logger, "end-linear-iterate", "status = continue");
+    SUNLogInfo(S->sunctx->logger, "end-iterations-list", "status = continue");
   }
 
   /* Failed to converge, even after allowed restarts.
@@ -889,7 +891,7 @@ int SUNLinSolSolve_SPGMR(SUNLinearSolver S, SUNDIALS_MAYBE_UNUSED SUNMatrix A,
         LASTFLAG(S) = (status < 0) ? SUNLS_PSOLVE_FAIL_UNREC
                                    : SUNLS_PSOLVE_FAIL_REC;
 
-        SUNLogInfo(S->sunctx->logger, "end-linear-iterate",
+        SUNLogInfo(S->sunctx->logger, "end-iterations-list",
                    "status = failed preconditioner solve, retval = %d", status);
 
         return (LASTFLAG(S));
@@ -916,7 +918,7 @@ int SUNLinSolSolve_SPGMR(SUNLinearSolver S, SUNDIALS_MAYBE_UNUSED SUNMatrix A,
     *zeroguess  = SUNFALSE;
     LASTFLAG(S) = SUNLS_RES_REDUCED;
 
-    SUNLogInfo(S->sunctx->logger, "end-linear-iterate",
+    SUNLogInfo(S->sunctx->logger, "end-iterations-list",
                "status = failed residual reduced");
 
     return (LASTFLAG(S));
@@ -925,7 +927,7 @@ int SUNLinSolSolve_SPGMR(SUNLinearSolver S, SUNDIALS_MAYBE_UNUSED SUNMatrix A,
   *zeroguess  = SUNFALSE;
   LASTFLAG(S) = SUNLS_CONV_FAIL;
 
-  SUNLogInfo(S->sunctx->logger, "end-linear-iterate",
+  SUNLogInfo(S->sunctx->logger, "end-iterations-list",
              "status = failed max iterations");
 
   return (LASTFLAG(S));
